==> resttools-1.1.23-sources.jar: com/humandevice/android/resttools/rest/exceptions/RequestException.java <==
package com.humandevice.android.resttools.rest.exceptions;

import android.support.annotation.NonNull;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.ObjectReader;
import com.fasterxml.jackson.databind.PropertyNamingStrategy;

import java.io.IOException;
import java.util.Arrays;
import java.util.Map;
import java.util.concurrent.ExecutionException;

/**
 * Exception rzucany w przypadku prawidłowej odpowiedzi z serwera zawierającej informacje o błędzie
 *
 * @author Rafal Zajfert
 * @date 29.02.2016
 */
@SuppressWarnings("unused")
public class RequestException extends ExecutionException {

    /**
     * Request completed
     */
    public static final int CODE_OK = 200;

    /**
     * Request accepted but data is incomplete / invalid
     */
    public static final int CODE_ACCEPTED = 202;

    /**
     * The request was invalid. You may be missing a required argument or provided bad data. An error mMessage will be returned explaining what happened.
     */
    public static final int CODE_BAD_REQUEST = 400;
    /**
     * The authentication you provided is invalid.
     */
    public static final int CODE_UNAUTHORIZED = 401;
    /**
     * You don't have permission to complete the operation or access the resource.
     */
    public static final int CODE_FORBIDDEN = 403;
    /**
     * You requested an invalid method.
     */
    public static final int CODE_NOT_FOUND = 404;
    /**
     * The method specified in the Request-Line is not allowed for the resource identified by the Request-URI. (used POST instead of PUT)
     */
    public static final int CODE_METHOD_NOT_ALLOWED = 405;
    /**
     * The server timed out waiting for the request.
     */
    public static final int CODE_TIMEOUT = 408;
    /**
     * You have exceeded the rate limit.
     */
    public static final int CODE_TOO_MANY_REQUESTS = 429;
    /**
     * Something is wrong on our end. We'll investigate what happened.
     */
    public static final int CODE_INTERNAL_SERVER_ERROR = 500;
    /**
     * The method you requested is currently unavailable (due to maintenance or high load).
     */
    public static final int CODE_SERVICE_UNAVAILABLE = 503;
    /**
     * Non server exception
     */
    public static final int UNKNOWN = -1;
    /**
     * Waiting thread is activated before the condition it was waiting for has been satisfied.
     */
    public static final int INTERRUPTED = -2;
    /**
     * Blocking operation times out
     */
    public static final int TIMEOUT = -3;

    @NonNull
    protected ErrorResponse mErrorResponse;

    protected RequestException(){
        super();
    }

    protected RequestException(String msg){
        super(msg);
    }

    public RequestException(@NonNull Exception e) {
        super(e);
        mErrorResponse = createResponseObject();
        mErrorResponse.parse(e);
    }

    protected ErrorResponse createResponseObject() {
        ErrorResponse response;
        Class<? extends ErrorResponse> responseClass = ExceptionRequest.getConfiguration().getErrorResponseClass();
        if (responseClass == null){
            response = new BaseErrorResponse();
        } else {
            try {
                response = responseClass.newInstance();
            } catch (Exception ex) {
                throw new RuntimeException(responseClass.getSimpleName() + " must have public default constructor");
            }
        }
        return response;
    }

    /**
     * Konstruktor wyjątku parsujący odpowiedź z serwera
     */
    public RequestException(@NonNull String errorJson, int requestCode) throws IOException {
        ObjectMapper objectMapper = new ObjectMapper();
        objectMapper.setPropertyNamingStrategy(PropertyNamingStrategy.SNAKE_CASE);
        ObjectReader errorReader;

        Class<? extends ErrorResponse> responseClass = ExceptionRequest.getConfiguration().getErrorResponseClass();
        if (responseClass == null) {
            errorReader = objectMapper.readerFor(BaseErrorResponse.class);
        } else {
            errorReader = objectMapper.readerFor(responseClass);
        }
        mErrorResponse = errorReader.readValue(errorJson);
        mErrorResponse.setStatusCode(requestCode);
    }

    /**
     * Metoda sprawdzająca czy exception został wywołany na etapie połączenia z serwerem
     */
    public boolean isConnectionError() {
        return mErrorResponse.getStatusCode() <= 0;
    }

    /**
     * Metoda sprawdzająca czy exception został wywołany na serwerze i został zwrócony json błędu
     */
    public boolean isResponseError() {
        return mErrorResponse.getStatusCode() > 0;
    }

    /**
     * Wiadomość błędu
     */
    @Override
    public String getMessage() {
        return mErrorResponse.getMessage();
    }

    /**
     * Kod błędu
     */
    public int getCode() {
        return mErrorResponse.getCode();
    }

    /**
     * Kod odpowiedzi
     */
    public int getStatusCode() {
        return mErrorResponse.getStatusCode();
    }

    /**
     * błędy w formularzu
     *
     * @return mapa błędów gdzie klucz to nazwa pola, a wartość to błędy
     */
    public Map<String, String[]> getErrors() {
        return mErrorResponse.getErrors();
    }

    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder(getMessage());
        for (Map.Entry<String, String[]> entry : getErrors().entrySet()) {
            builder.append("\n");
            builder.append(entry.getKey()).append(": ").append(Arrays.toString(entry.getValue()));
        }
        return builder.toString();
    }
}

==> resttools-1.1.34-sources.jar: com/humandevice/android/resttools/rest/exceptions/RequestException.java <==
package com.humandevice.android.resttools.rest.exceptions;

import android.support.annotation.NonNull;
import android.text.TextUtils;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.ObjectReader;
import com.fasterxml.jackson.databind.PropertyNamingStrategy;

import java.io.IOException;
import java.util.Arrays;
import java.util.Map;
import java.util.concurrent.ExecutionException;

/**
 * Exception rzucany w przypadku prawidłowej odpowiedzi z serwera zawierającej informacje o błędzie
 *
 * @author Rafal Zajfert
 * @date 29.02.2016
 */
@SuppressWarnings("unused")
public class RequestException extends ExecutionException {

    /**
     * Request completed
     */
    public static final int CODE_OK = 200;

    /**
     * Request accepted but data is incomplete / invalid
     */
    public static final int CODE_ACCEPTED = 202;

    /**
     * The request was invalid. You may be missing a required argument or provided bad data. An error mMessage will be returned explaining what happened.
     */
    public static final int CODE_BAD_REQUEST = 400;
    /**
     * The authentication you provided is invalid.
     */
    public static final int CODE_UNAUTHORIZED = 401;
    /**
     * You don't have permission to complete the operation or access the resource.
     */
    public static final int CODE_FORBIDDEN = 403;
    /**
     * You requested an invalid method.
     */
    public static final int CODE_NOT_FOUND = 404;
    /**
     * The method specified in the Request-Line is not allowed for the resource identified by the Request-URI. (used POST instead of PUT)
     */
    public static final int CODE_METHOD_NOT_ALLOWED = 405;
    /**
     * The server timed out waiting for the request.
     */
    public static final int CODE_TIMEOUT = 408;
    /**
     * You have exceeded the rate limit.
     */
    public static final int CODE_TOO_MANY_REQUESTS = 429;
    /**
     * Something is wrong on our end. We'll investigate what happened.
     */
    public static final int CODE_INTERNAL_SERVER_ERROR = 500;
    /**
     * The method you requested is currently unavailable (due to maintenance or high load).
     */
    public static final int CODE_SERVICE_UNAVAILABLE = 503;
    /**
     * Non server exception
     */
    public static final int UNKNOWN = -1;
    /**
     * Waiting thread is activated before the condition it was waiting for has been satisfied.
     */
    public static final int INTERRUPTED = -2;
    /**
     * Blocking operation times out
     */
    public static final int TIMEOUT = -3;

    @NonNull
    protected ErrorResponse mErrorResponse;

    protected RequestException(){
        super();
    }

    protected RequestException(String msg){
        super(msg);
    }

    public RequestException(@NonNull Exception e) {
        super(e);
        mErrorResponse = createResponseObject();
        mErrorResponse.parse(e);
    }

    protected ErrorResponse createResponseObject() {
        ErrorResponse response;
        Class<? extends ErrorResponse> responseClass = ExceptionRequest.getConfiguration().getErrorResponseClass();
        if (responseClass == null){
            response = new BaseErrorResponse();
        } else {
            try {
                response = responseClass.newInstance();
            } catch (Exception ex) {
                throw new RuntimeException(responseClass.getSimpleName() + " must have public default constructor");
            }
        }
        return response;
    }

    /**
     * Konstruktor wyjątku parsujący odpowiedź z serwera
     */
    public RequestException(@NonNull String errorJson, int requestCode) throws IOException {
        ObjectMapper objectMapper = new ObjectMapper();
        objectMapper.setPropertyNamingStrategy(PropertyNamingStrategy.SNAKE_CASE);
        ObjectReader errorReader;

        Class<? extends ErrorResponse> responseClass = ExceptionRequest.getConfiguration().getErrorResponseClass();
        if (responseClass == null) {
            errorReader = objectMapper.readerFor(BaseErrorResponse.class);
        } else {
            errorReader = objectMapper.readerFor(responseClass);
        }
        mErrorResponse = errorReader.readValue(errorJson);
        mErrorResponse.setStatusCode(requestCode);
    }

    /**
     * Metoda sprawdzająca czy exception został wywołany na etapie połączenia z serwerem
     */
    public boolean isConnectionError() {
        return mErrorResponse.getStatusCode() <= 0;
    }

    /**
     * Metoda sprawdzająca czy exception został wywołany na serwerze i został zwrócony json błędu
     */
    public boolean isResponseError() {
        return mErrorResponse.getStatusCode() > 0;
    }

    /**
     * Wiadomość błędu
     */
    @Override
    public String getMessage() {
        return mErrorResponse.getMessage();
    }

    /**
     * Kod błędu
     */
    public int getCode() {
        return mErrorResponse.getCode();
    }

    /**
     * Kod odpowiedzi
     */
    public int getStatusCode() {
        return mErrorResponse.getStatusCode();
    }

    /**
     * błędy w formularzu
     *
     * @return mapa błędów gdzie klucz to nazwa pola, a wartość to błędy
     */
    public Map<String, String[]> getErrors() {
        return mErrorResponse.getErrors();
    }

    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder();
        String message = getMessage();
        if (!TextUtils.isEmpty(message)){
            builder.append(message);
        }
        for (Map.Entry<String, String[]> entry : getErrors().entrySet()) {
            builder.append("\n");
            builder.append(entry.getKey()).append(": ").append(Arrays.toString(entry.getValue()));
        }
        return builder.toString();
    }
}
